==> percona-server-mongodb_4.0.18.orig.tar.gz: percona-server-mongodb-4.0.18-11/aws-sdk-cpp/aws-cpp-sdk-ec2/source/model/DirectoryServiceAuthentication.cpp <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/ec2/model/DirectoryServiceAuthentication.h>
#include <aws/core/utils/xml/XmlSerializer.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::Utils::Xml;
using namespace Aws::Utils;

namespace Aws
{
namespace EC2
{
namespace Model
{

DirectoryServiceAuthentication::DirectoryServiceAuthentication() : 
    m_directoryIdHasBeenSet(false)
{
}

DirectoryServiceAuthentication::DirectoryServiceAuthentication(const XmlNode& xmlNode) : 
    m_directoryIdHasBeenSet(false)
{
  *this = xmlNode;
}

DirectoryServiceAuthentication& DirectoryServiceAuthentication::operator =(const XmlNode& xmlNode)
{
  XmlNode resultNode = xmlNode;

  if(!resultNode.IsNull())
  {
    XmlNode directoryIdNode = resultNode.FirstChild("directoryId");
    if(!directoryIdNode.IsNull())
    {
      m_directoryId = StringUtils::Trim(directoryIdNode.GetText().c_str());
      m_directoryIdHasBeenSet = true;
    }
  }

  return *this;
}

void DirectoryServiceAuthentication::OutputToStream(Aws::OStream& oStream, const char* location, unsigned index, const char* locationValue) const
{
  if(m_directoryIdHasBeenSet)
  {
      oStream << location << index << locationValue << ".DirectoryId=" << StringUtils::URLEncode(m_directoryId.c_str()) << "&";
  }

}

void DirectoryServiceAuthentication::OutputToStream(Aws::OStream& oStream, const char* location) const
{
  if(m_directoryIdHasBeenSet)
  {
      oStream << location << ".DirectoryId=" << StringUtils::URLEncode(m_directoryId.c_str()) << "&";
  }
}

} // namespace Model
} // namespace EC2
} // namespace Aws

==> percona-server-mongodb_5.0.9.orig.tar.gz: percona-server-mongodb-5.0.9-8/aws-sdk-cpp/aws-cpp-sdk-ec2/source/model/DirectoryServiceAuthentication.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/ec2/model/DirectoryServiceAuthentication.h>
#include <aws/core/utils/xml/XmlSerializer.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::Utils::Xml;
using namespace Aws::Utils;

namespace Aws
{
namespace EC2
{
namespace Model
{

DirectoryServiceAuthentication::DirectoryServiceAuthentication() : 
    m_directoryIdHasBeenSet(false)
{
}

DirectoryServiceAuthentication::DirectoryServiceAuthentication(const XmlNode& xmlNode) : 
    m_directoryIdHasBeenSet(false)
{
  *this = xmlNode;
}

DirectoryServiceAuthentication& DirectoryServiceAuthentication::operator =(const XmlNode& xmlNode)
{
  XmlNode resultNode = xmlNode;

  if(!resultNode.IsNull())
  {
    XmlNode directoryIdNode = resultNode.FirstChild("directoryId");
    if(!directoryIdNode.IsNull())
    {
      m_directoryId = Aws::Utils::Xml::DecodeEscapedXmlText(directoryIdNode.GetText());
      m_directoryIdHasBeenSet = true;
    }
  }

  return *this;
}

void DirectoryServiceAuthentication::OutputToStream(Aws::OStream& oStream, const char* location, unsigned index, const char* locationValue) const
{
  if(m_directoryIdHasBeenSet)
  {
      oStream << location << index << locationValue << ".DirectoryId=" << StringUtils::URLEncode(m_directoryId.c_str()) << "&";
  }

}

void DirectoryServiceAuthentication::OutputToStream(Aws::OStream& oStream, const char* location) const
{
  if(m_directoryIdHasBeenSet)
  {
      oStream << location << ".DirectoryId=" << StringUtils::URLEncode(m_directoryId.c_str()) << "&";
  }
}

} // namespace Model
} // namespace EC2
} // namespace Aws
